# Indian Facial Expression Dataset

<p align="center">
  <img src="https://github.com/Nikeshbajaj/ifexd/raw/master/images/S1.jpg" width="900"/>
</p>

### Links: **[Homepage](https://ifexd.github.io)** | **[Github](https://github.com/Nikeshbajaj/ifexd)**  |  **[PyPi - project](https://pypi.org/project/ifexd/)** |

**Indian Facial Expression Dataset**
* 12K images including three views - Front, Left, Right
* Images from 345 Indians
* 7 Expressions + Natural pose:
  * A: Natural
  * B: Happy
  * C: Surprise
  * D: Sad
  * E: Anger
  * F: Contempt
  * G: Disgust
  * H: Fear


______________________________________

# Contacts:

* **Nikesh Bajaj**
* http://nikeshbajaj.in
### PhD Student: Queen Mary University of London
______________________________________
